//
//  NoteEditViewController.m
//  MagicNotes
//
//  Created by Nick Jones on 06/05/2013.
//  Copyright (c) 2013 sigfrid. All rights reserved.
//

#import "NoteEditViewController.h"
#import "Note+Create.h"

@interface NoteEditViewController ()
@property (strong, nonatomic) Note *note;
@property (nonatomic) BOOL isNewNote;
@end

@implementation NoteEditViewController
@synthesize note=_note;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view.
    [self initView];
    [self setupGestures];
}

-(void) setupGestures {
    UITapGestureRecognizer *gestureRecognizer = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(hideKeyboard)];
    [self.view addGestureRecognizer:gestureRecognizer];
    gestureRecognizer.cancelsTouchesInView = NO;
}

-(void) hideKeyboard {
    [self.view endEditing:YES];
}

-(void) initView {
    self.navigationItem.hidesBackButton = YES;
    UIBarButtonItem *cancelButton = [[UIBarButtonItem alloc] initWithTitle:@"Cancel" style:UIBarButtonItemStyleBordered target:self action:@selector(cancel:)];
    self.navigationItem.leftBarButtonItem = cancelButton;
    // Create Save Button
    UIBarButtonItem *saveButton = [[UIBarButtonItem alloc] initWithTitle:@"Save" style:UIBarButtonItemStyleBordered target:self action:@selector(save:)];
    self.navigationItem.rightBarButtonItem = saveButton;
    
    if (!self.note) {
        self.note = [Note MR_createEntity];
        self.note.date = [NSDate date];
        self.isNewNote = YES;
    }
    else self.isNewNote = NO;
    
    UIDatePicker *picker = [[UIDatePicker alloc] init];
    [picker addTarget:self
               action:@selector(dateChanged:)
     forControlEvents:UIControlEventValueChanged];
    self.dateField.inputView = picker;
    
    self.titleField.text = self.note.title;
    self.contentField.text = self.note.content;
    
    [self setupDate];
}

- (void)setupDate {
    self.dateField.text = [self.note formatDateAsString];
}

-(IBAction) dateChanged:(UIDatePicker*)picker {
    self.note.date = picker.date;
    [self setupDate];
}

- (void)cancel:(id)sender {
    // Dismiss View Controller
    if(self.isNewNote) [self.note MR_deleteEntity];
    [self.navigationController popViewControllerAnimated:YES];
}

-(void) save:(id) sender {
    self.note.title = self.titleField.text;
    // note.date is already set when datepicker changes
    self.note.content = self.contentField.text;
    NSManagedObjectContext *localContext = [NSManagedObjectContext MR_contextForCurrentThread];
    [localContext MR_saveToPersistentStoreWithCompletion:nil];
    [self.navigationController popViewControllerAnimated:YES];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

@end
