//
//  NotesListViewController.m
//  MagicNotes
//
//  Created by Nick Jones on 04/05/2013.
//  Copyright (c) 2013 sigfrid. All rights reserved.
//

#import "NotesListViewController.h"
#import "Note+Create.h"

@interface NotesListViewController ()
@end

@implementation NotesListViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view.
    [self setupView];
    [self setupFetchedResultsController];
}

- (void)setupView {
    // Create Edit Button
    UIBarButtonItem *editButton = [[UIBarButtonItem alloc] initWithTitle:@"Edit" style:UIBarButtonItemStyleBordered target:self action:@selector(editNotes:)];
    self.navigationItem.leftBarButtonItem = editButton;
    // Create Add Button
    UIBarButtonItem *addButton = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemAdd target:self action:@selector(addNote:)];
    self.navigationItem.rightBarButtonItem = addButton;
}


-(void) addTestRecord {
    Note *test = [Note MR_createEntity];
    test.title = @"Note 1";
    test.date = [NSDate date];
    test.content = @"Test content for note 1";
    
    Note *test2 = [Note MR_createEntity];
    test2.title = @"Note 2";
    test2.date = [NSDate dateWithTimeIntervalSinceNow:-2*24*60*60];
    test2.content = @"Test content for note 2";
    
    NSManagedObjectContext *localContext = [NSManagedObjectContext MR_contextForCurrentThread];
    [localContext MR_saveToPersistentStoreWithCompletion:nil];
}

-(void) addNote:(id) sender {
    [self performSegueWithIdentifier:@"listToEditNote" sender:nil];
}

- (void)editNotes:(UIBarButtonItem*)sender {
    [self.tableView setEditing:![self.tableView isEditing] animated:YES];
    [self.tableView isEditing]? [sender setTitle:@"Done"]:[sender setTitle:@"Edit"];
}

- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath {
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        Note *note = [self.fetchedResultsController objectAtIndexPath:indexPath];
        // Delete Note from Data Source
        [note MR_deleteEntity];
        NSManagedObjectContext *localContext = [NSManagedObjectContext MR_contextForCurrentThread];
        [localContext MR_saveToPersistentStoreWithCompletion:nil];
    }
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    if(tableView.editing) [self performSegueWithIdentifier:@"listToNote" sender:indexPath];
}

- (void)tableView:(UITableView *)tableView accessoryButtonTappedForRowWithIndexPath:(NSIndexPath *)indexPath {
    [self performSegueWithIdentifier:@"listToEditNote" sender:indexPath];
}


#pragma mark setup fetched results controller
- (void)setupFetchedResultsController {
    self.fetchedResultsController = [Note MR_fetchAllGroupedBy:nil withPredicate:nil sortedBy:@"date" ascending:NO];
}

#pragma mark tableView methods
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Note Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier];
        cell.textLabel.font = [UIFont systemFontOfSize:19.0];
        cell.detailTextLabel.font = [UIFont systemFontOfSize:12];
    }
    
    // We will configure the cell details here
    //** Add the code below **
    Note *note = [self.fetchedResultsController objectAtIndexPath:indexPath];
    cell.textLabel.text = note.title;
    cell.detailTextLabel.text=[note formatDateAsString];

    return cell;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark Segue
-(void) prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    if ([segue.destinationViewController respondsToSelector:@selector(setNote:)]){
        [segue.destinationViewController performSelector:@selector(setNote:) withObject:[self.fetchedResultsController objectAtIndexPath:sender]];
    }
}


@end
